@@ -8,9 +8,9 @@ use Try::Tiny;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use Hash::Merge 'merge';
-use Moose;
+use Mouse;
 
-our $VERSION = '0.951';
+our $VERSION = '0.952';
 
 has sqitch => (
     is       => 'ro',
@@ -172,7 +172,7 @@ sub usage {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Mouse;
 
 __END__
 
