@@ -7,15 +7,15 @@ use utf8;
 use Template::Tiny 0.11;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Moose;
-use MooseX::Types::Path::Class;
+use Mouse;
+use MouseX::Types::Path::Class;
 use Path::Class;
 use File::Path qw(make_path);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.951';
+our $VERSION = '0.952';
 
 has requires => (
     is       => 'ro',
