@@ -7,10 +7,10 @@ use utf8;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use Pod::Find;
-use Moose;
+use Mouse;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.951';
+our $VERSION = '0.952';
 
 # XXX Add --all at some point, to output a list of all possible commands.
 
