@@ -4,13 +4,13 @@ use 5.010;
 use strict;
 use warnings;
 use utf8;
-use Moose;
-use Moose::Util::TypeConstraints;
+use Mouse;
+use Mouse::Util::TypeConstraints;
 use List::Util qw(first);
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.951';
+our $VERSION = '0.952';
 
 has to_target => (
     is  => 'ro',
